# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'negar_gui/mwin.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1059, 790)
        MainWindow.setFocusPolicy(QtCore.Qt.StrongFocus)
        MainWindow.setLayoutDirection(QtCore.Qt.LeftToRight)
        MainWindow.setAutoFillBackground(False)
        MainWindow.setStyleSheet("QFrame {\n"
"    border: none;\n"
"    margin: 0px;\n"
"    padding: 0px;\n"
"}")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.centralwidget.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.centralwidget.setAutoFillBackground(True)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.frame_6 = QtWidgets.QFrame(self.centralwidget)
        self.frame_6.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_6.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_6.setObjectName("frame_6")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.frame_6)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frame = QtWidgets.QFrame(self.frame_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.frame)
        self.gridLayout_5.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.frame_2 = QtWidgets.QFrame(self.frame)
        self.frame_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.frame_2)
        self.gridLayout_4.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_4.setSpacing(0)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.reset_btn = QtWidgets.QPushButton(self.frame_2)
        self.reset_btn.setStyleSheet("")
        self.reset_btn.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/reset.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.reset_btn.setIcon(icon)
        self.reset_btn.setShortcut("")
        self.reset_btn.setObjectName("reset_btn")
        self.gridLayout_4.addWidget(self.reset_btn, 0, 0, 1, 1)
        self.copy_btn = QtWidgets.QPushButton(self.frame_2)
        self.copy_btn.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/copy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.copy_btn.setIcon(icon1)
        self.copy_btn.setShortcut("")
        self.copy_btn.setObjectName("copy_btn")
        self.gridLayout_4.addWidget(self.copy_btn, 0, 1, 1, 1)
        self.paste_btn = QtWidgets.QPushButton(self.frame_2)
        self.paste_btn.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/images/icons/paste.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.paste_btn.setIcon(icon2)
        self.paste_btn.setShortcut("")
        self.paste_btn.setObjectName("paste_btn")
        self.gridLayout_4.addWidget(self.paste_btn, 0, 2, 1, 1)
        self.qrcode_btn = QtWidgets.QPushButton(self.frame_2)
        self.qrcode_btn.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/images/icons/qr.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.qrcode_btn.setIcon(icon3)
        self.qrcode_btn.setShortcut("")
        self.qrcode_btn.setObjectName("qrcode_btn")
        self.gridLayout_4.addWidget(self.qrcode_btn, 0, 3, 1, 1)
        self.vertical_btn = QtWidgets.QPushButton(self.frame_2)
        self.vertical_btn.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/images/icons/vertical.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.vertical_btn.setIcon(icon4)
        self.vertical_btn.setShortcut("")
        self.vertical_btn.setObjectName("vertical_btn")
        self.gridLayout_4.addWidget(self.vertical_btn, 0, 4, 1, 1)
        self.horizontal_btn = QtWidgets.QPushButton(self.frame_2)
        self.horizontal_btn.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/images/icons/horizontal.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.horizontal_btn.setIcon(icon5)
        self.horizontal_btn.setShortcut("")
        self.horizontal_btn.setObjectName("horizontal_btn")
        self.gridLayout_4.addWidget(self.horizontal_btn, 0, 5, 1, 1)
        self.gridLayout_5.addWidget(self.frame_2, 0, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(210, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem, 0, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(210, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem1, 0, 2, 1, 1)
        self.frame_4 = QtWidgets.QFrame(self.frame)
        self.frame_4.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_4.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_4.setObjectName("frame_4")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.frame_4)
        self.gridLayout_3.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_3.setVerticalSpacing(0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.font_slider_label = QtWidgets.QLabel(self.frame_4)
        self.font_slider_label.setObjectName("font_slider_label")
        self.gridLayout_3.addWidget(self.font_slider_label, 0, 0, 1, 1)
        self.font_slider = QtWidgets.QSlider(self.frame_4)
        self.font_slider.setMinimum(10)
        self.font_slider.setMaximum(72)
        self.font_slider.setProperty("value", 18)
        self.font_slider.setOrientation(QtCore.Qt.Horizontal)
        self.font_slider.setObjectName("font_slider")
        self.gridLayout_3.addWidget(self.font_slider, 0, 1, 1, 1)
        self.gridLayout_5.addWidget(self.frame_4, 0, 3, 1, 1)
        self.frame_3 = QtWidgets.QFrame(self.frame)
        self.frame_3.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_3.setObjectName("frame_3")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.frame_3)
        self.gridLayout_7.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_7.setVerticalSpacing(0)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.edit_btn = QtWidgets.QPushButton(self.frame_3)
        self.edit_btn.setEnabled(False)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/images/icons/edit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.edit_btn.setIcon(icon6)
        self.edit_btn.setObjectName("edit_btn")
        self.gridLayout_7.addWidget(self.edit_btn, 0, 1, 1, 1)
        self.autoedit_chkbox = QtWidgets.QCheckBox(self.frame_3)
        self.autoedit_chkbox.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.autoedit_chkbox.setChecked(True)
        self.autoedit_chkbox.setObjectName("autoedit_chkbox")
        self.gridLayout_7.addWidget(self.autoedit_chkbox, 0, 0, 1, 1)
        self.gridLayout_5.addWidget(self.frame_3, 0, 4, 1, 1)
        self.verticalLayout.addWidget(self.frame)
        self.frame_5 = QtWidgets.QFrame(self.frame_6)
        self.frame_5.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_5.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_5.setObjectName("frame_5")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.frame_5)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setSpacing(0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.input_layout = QtWidgets.QGridLayout()
        self.input_layout.setObjectName("input_layout")
        self.input_editor_label = QtWidgets.QLabel(self.frame_5)
        self.input_editor_label.setObjectName("input_editor_label")
        self.input_layout.addWidget(self.input_editor_label, 0, 0, 1, 1)
        self.input_editor = QtWidgets.QTextEdit(self.frame_5)
        self.input_editor.setObjectName("input_editor")
        self.input_layout.addWidget(self.input_editor, 1, 0, 1, 1)
        self.gridLayout.addLayout(self.input_layout, 0, 0, 1, 1)
        self.output_editor_label = QtWidgets.QLabel(self.frame_5)
        self.output_editor_label.setObjectName("output_editor_label")
        self.gridLayout.addWidget(self.output_editor_label, 1, 0, 1, 1)
        self.output_editor = QtWidgets.QTextEdit(self.frame_5)
        self.output_editor.setObjectName("output_editor")
        self.gridLayout.addWidget(self.output_editor, 2, 0, 1, 1)
        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 1)
        self.verticalLayout.addWidget(self.frame_5)
        self.gridLayout_6.addWidget(self.frame_6, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1059, 27))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuSetting = QtWidgets.QMenu(self.menubar)
        self.menuSetting.setObjectName("menuSetting")
        self.menuOptions = QtWidgets.QMenu(self.menuSetting)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/images/icons/options.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.menuOptions.setIcon(icon7)
        self.menuOptions.setSeparatorsCollapsible(True)
        self.menuOptions.setObjectName("menuOptions")
        self.menuLanguage = QtWidgets.QMenu(self.menuSetting)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/images/icons/languages.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.menuLanguage.setIcon(icon8)
        self.menuLanguage.setObjectName("menuLanguage")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.menuHelp.sizePolicy().hasHeightForWidth())
        self.menuHelp.setSizePolicy(sizePolicy)
        self.menuHelp.setObjectName("menuHelp")
        self.menuEdit = QtWidgets.QMenu(self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.menu_View = QtWidgets.QMenu(self.menubar)
        self.menu_View.setObjectName("menu_View")
        MainWindow.setMenuBar(self.menubar)
        self.statusBar = QtWidgets.QStatusBar(MainWindow)
        self.statusBar.setObjectName("statusBar")
        MainWindow.setStatusBar(self.statusBar)
        self.actionOpen = QtWidgets.QAction(MainWindow)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/images/icons/open.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionOpen.setIcon(icon9)
        self.actionOpen.setShortcut("Ctrl+O")
        self.actionOpen.setObjectName("actionOpen")
        self.actionExport = QtWidgets.QAction(MainWindow)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/images/icons/export.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionExport.setIcon(icon10)
        self.actionExport.setShortcut("Ctrl+E")
        self.actionExport.setObjectName("actionExport")
        self.actionExit = QtWidgets.QAction(MainWindow)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/images/icons/exit.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionExit.setIcon(icon11)
        self.actionExit.setShortcut("Ctrl+Q")
        self.actionExit.setObjectName("actionExit")
        self.actionAbout_Negar = QtWidgets.QAction(MainWindow)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/images/icons/about.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionAbout_Negar.setIcon(icon12)
        self.actionAbout_Negar.setShortcut("")
        self.actionAbout_Negar.setObjectName("actionAbout_Negar")
        self.actionDonate = QtWidgets.QAction(MainWindow)
        self.actionDonate.setEnabled(False)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/images/icons/donate.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDonate.setIcon(icon13)
        self.actionDonate.setShortcut("")
        self.actionDonate.setObjectName("actionDonate")
        self.actionReport_Bugs = QtWidgets.QAction(MainWindow)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/images/icons/bugs.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionReport_Bugs.setIcon(icon14)
        self.actionReport_Bugs.setObjectName("actionReport_Bugs")
        self.actionNegar_Help = QtWidgets.QAction(MainWindow)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/images/icons/logo.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionNegar_Help.setIcon(icon15)
        self.actionNegar_Help.setShortcut("F1")
        self.actionNegar_Help.setObjectName("actionNegar_Help")
        self.actionFix_Dashes = QtWidgets.QAction(MainWindow)
        self.actionFix_Dashes.setCheckable(True)
        self.actionFix_Dashes.setChecked(True)
        self.actionFix_Dashes.setObjectName("actionFix_Dashes")
        self.actionFix_three_dots = QtWidgets.QAction(MainWindow)
        self.actionFix_three_dots.setCheckable(True)
        self.actionFix_three_dots.setChecked(True)
        self.actionFix_three_dots.setObjectName("actionFix_three_dots")
        self.actionFix_English_quotes = QtWidgets.QAction(MainWindow)
        self.actionFix_English_quotes.setCheckable(True)
        self.actionFix_English_quotes.setChecked(True)
        self.actionFix_English_quotes.setObjectName("actionFix_English_quotes")
        self.actionFix_hamzeh = QtWidgets.QAction(MainWindow)
        self.actionFix_hamzeh.setCheckable(True)
        self.actionFix_hamzeh.setChecked(True)
        self.actionFix_hamzeh.setObjectName("actionFix_hamzeh")
        self.actionUse_Persian_yeh_to_show_hamzeh = QtWidgets.QAction(MainWindow)
        self.actionUse_Persian_yeh_to_show_hamzeh.setCheckable(True)
        self.actionUse_Persian_yeh_to_show_hamzeh.setChecked(True)
        self.actionUse_Persian_yeh_to_show_hamzeh.setObjectName("actionUse_Persian_yeh_to_show_hamzeh")
        self.actionFix_spacing_braces_and_quotes = QtWidgets.QAction(MainWindow)
        self.actionFix_spacing_braces_and_quotes.setCheckable(True)
        self.actionFix_spacing_braces_and_quotes.setChecked(True)
        self.actionFix_spacing_braces_and_quotes.setObjectName("actionFix_spacing_braces_and_quotes")
        self.actionFix_Arabic_numbers = QtWidgets.QAction(MainWindow)
        self.actionFix_Arabic_numbers.setCheckable(True)
        self.actionFix_Arabic_numbers.setChecked(True)
        self.actionFix_Arabic_numbers.setObjectName("actionFix_Arabic_numbers")
        self.actionFix_English_numbers = QtWidgets.QAction(MainWindow)
        self.actionFix_English_numbers.setCheckable(True)
        self.actionFix_English_numbers.setChecked(True)
        self.actionFix_English_numbers.setObjectName("actionFix_English_numbers")
        self.actionFix_non_Persian_chars = QtWidgets.QAction(MainWindow)
        self.actionFix_non_Persian_chars.setCheckable(True)
        self.actionFix_non_Persian_chars.setChecked(True)
        self.actionFix_non_Persian_chars.setObjectName("actionFix_non_Persian_chars")
        self.actionFix_prefix_spacing = QtWidgets.QAction(MainWindow)
        self.actionFix_prefix_spacing.setCheckable(True)
        self.actionFix_prefix_spacing.setChecked(True)
        self.actionFix_prefix_spacing.setObjectName("actionFix_prefix_spacing")
        self.actionFix_prefix_separating = QtWidgets.QAction(MainWindow)
        self.actionFix_prefix_separating.setCheckable(True)
        self.actionFix_prefix_separating.setChecked(True)
        self.actionFix_prefix_separating.setObjectName("actionFix_prefix_separating")
        self.actionFix_suffix_spacing = QtWidgets.QAction(MainWindow)
        self.actionFix_suffix_spacing.setCheckable(True)
        self.actionFix_suffix_spacing.setChecked(True)
        self.actionFix_suffix_spacing.setObjectName("actionFix_suffix_spacing")
        self.actionFix_suffix_separating = QtWidgets.QAction(MainWindow)
        self.actionFix_suffix_separating.setCheckable(True)
        self.actionFix_suffix_separating.setChecked(True)
        self.actionFix_suffix_separating.setObjectName("actionFix_suffix_separating")
        self.actionFix_aggressive_punctuation = QtWidgets.QAction(MainWindow)
        self.actionFix_aggressive_punctuation.setCheckable(True)
        self.actionFix_aggressive_punctuation.setChecked(True)
        self.actionFix_aggressive_punctuation.setObjectName("actionFix_aggressive_punctuation")
        self.actionCleanup_kashidas = QtWidgets.QAction(MainWindow)
        self.actionCleanup_kashidas.setCheckable(True)
        self.actionCleanup_kashidas.setChecked(True)
        self.actionCleanup_kashidas.setObjectName("actionCleanup_kashidas")
        self.actionCleanup_extra_marks = QtWidgets.QAction(MainWindow)
        self.actionCleanup_extra_marks.setCheckable(True)
        self.actionCleanup_extra_marks.setChecked(True)
        self.actionCleanup_extra_marks.setObjectName("actionCleanup_extra_marks")
        self.actionCleanup_spacing = QtWidgets.QAction(MainWindow)
        self.actionCleanup_spacing.setCheckable(True)
        self.actionCleanup_spacing.setChecked(True)
        self.actionCleanup_spacing.setObjectName("actionCleanup_spacing")
        self.actionTrim_Leading_Trailing_Whitespaces = QtWidgets.QAction(MainWindow)
        self.actionTrim_Leading_Trailing_Whitespaces.setCheckable(True)
        self.actionTrim_Leading_Trailing_Whitespaces.setChecked(True)
        self.actionTrim_Leading_Trailing_Whitespaces.setObjectName("actionTrim_Leading_Trailing_Whitespaces")
        self.actionExaggerating_ZWNJ = QtWidgets.QAction(MainWindow)
        self.actionExaggerating_ZWNJ.setCheckable(True)
        self.actionExaggerating_ZWNJ.setChecked(True)
        self.actionExaggerating_ZWNJ.setObjectName("actionExaggerating_ZWNJ")
        self.actionUntouchable_Words = QtWidgets.QAction(MainWindow)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/images/icons/words.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionUntouchable_Words.setIcon(icon16)
        self.actionUntouchable_Words.setShortcut("")
        self.actionUntouchable_Words.setObjectName("actionUntouchable_Words")
        self.actionPersian = QtWidgets.QAction(MainWindow)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/images/icons/Fa.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPersian.setIcon(icon17)
        self.actionPersian.setShortcut("Ctrl+L, Ctrl+F")
        self.actionPersian.setObjectName("actionPersian")
        self.actionEnglish = QtWidgets.QAction(MainWindow)
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(":/images/icons/En.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionEnglish.setIcon(icon18)
        self.actionEnglish.setShortcut("Ctrl+L, Ctrl+E")
        self.actionEnglish.setObjectName("actionEnglish")
        self.actionCopy = QtWidgets.QAction(MainWindow)
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(":/images/icons/copy.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCopy.setIcon(icon19)
        self.actionCopy.setShortcut("Ctrl+C")
        self.actionCopy.setObjectName("actionCopy")
        self.actionPaste = QtWidgets.QAction(MainWindow)
        self.actionPaste.setIcon(icon2)
        self.actionPaste.setShortcut("Ctrl+V")
        self.actionPaste.setObjectName("actionPaste")
        self.actionIncrease_Font_Size = QtWidgets.QAction(MainWindow)
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(":/images/icons/increase.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionIncrease_Font_Size.setIcon(icon20)
        self.actionIncrease_Font_Size.setShortcut("Ctrl+=")
        self.actionIncrease_Font_Size.setObjectName("actionIncrease_Font_Size")
        self.actionDecrease_Font_Size = QtWidgets.QAction(MainWindow)
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap(":/images/icons/decrease.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDecrease_Font_Size.setIcon(icon21)
        self.actionDecrease_Font_Size.setShortcut("Ctrl+-")
        self.actionDecrease_Font_Size.setObjectName("actionDecrease_Font_Size")
        self.actionReset = QtWidgets.QAction(MainWindow)
        self.actionReset.setIcon(icon)
        self.actionReset.setShortcut("Ctrl+R")
        self.actionReset.setObjectName("actionReset")
        self.actionSide_by_Side_View = QtWidgets.QAction(MainWindow)
        self.actionSide_by_Side_View.setCheckable(True)
        self.actionSide_by_Side_View.setShortcut("Ctrl+S")
        self.actionSide_by_Side_View.setObjectName("actionSide_by_Side_View")
        self.actionAbout_Negar_GUI = QtWidgets.QAction(MainWindow)
        self.actionAbout_Negar_GUI.setObjectName("actionAbout_Negar_GUI")
        self.actionInteractive_Clipboard = QtWidgets.QAction(MainWindow)
        self.actionInteractive_Clipboard.setCheckable(True)
        self.actionInteractive_Clipboard.setShortcut("Ctrl+I")
        self.actionInteractive_Clipboard.setObjectName("actionInteractive_Clipboard")
        self.actionUpdate = QtWidgets.QAction(MainWindow)
        self.actionUpdate.setObjectName("actionUpdate")
        self.actionQr_Code = QtWidgets.QAction(MainWindow)
        self.actionQr_Code.setIcon(icon3)
        self.actionQr_Code.setObjectName("actionQr_Code")
        self.actionFull_Screen_Input = QtWidgets.QAction(MainWindow)
        self.actionFull_Screen_Input.setCheckable(True)
        self.actionFull_Screen_Input.setObjectName("actionFull_Screen_Input")
        self.action_Dark_Mode = QtWidgets.QAction(MainWindow)
        self.action_Dark_Mode.setCheckable(True)
        self.action_Dark_Mode.setEnabled(False)
        self.action_Dark_Mode.setObjectName("action_Dark_Mode")
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addAction(self.actionExport)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menuOptions.addAction(self.actionFix_Dashes)
        self.menuOptions.addAction(self.actionFix_three_dots)
        self.menuOptions.addAction(self.actionFix_English_quotes)
        self.menuOptions.addAction(self.actionFix_hamzeh)
        self.menuOptions.addAction(self.actionFix_spacing_braces_and_quotes)
        self.menuOptions.addAction(self.actionFix_Arabic_numbers)
        self.menuOptions.addAction(self.actionFix_English_numbers)
        self.menuOptions.addAction(self.actionFix_non_Persian_chars)
        self.menuOptions.addAction(self.actionFix_prefix_spacing)
        self.menuOptions.addAction(self.actionFix_prefix_separating)
        self.menuOptions.addAction(self.actionFix_suffix_spacing)
        self.menuOptions.addAction(self.actionFix_suffix_separating)
        self.menuOptions.addAction(self.actionFix_aggressive_punctuation)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionUse_Persian_yeh_to_show_hamzeh)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionCleanup_spacing)
        self.menuOptions.addAction(self.actionCleanup_kashidas)
        self.menuOptions.addAction(self.actionCleanup_extra_marks)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionExaggerating_ZWNJ)
        self.menuOptions.addAction(self.actionTrim_Leading_Trailing_Whitespaces)
        self.menuLanguage.addAction(self.actionPersian)
        self.menuLanguage.addAction(self.actionEnglish)
        self.menuSetting.addAction(self.menuOptions.menuAction())
        self.menuSetting.addAction(self.actionInteractive_Clipboard)
        self.menuSetting.addAction(self.menuLanguage.menuAction())
        self.menuSetting.addSeparator()
        self.menuSetting.addAction(self.actionUntouchable_Words)
        self.menuHelp.addAction(self.actionNegar_Help)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbout_Negar)
        self.menuHelp.addAction(self.actionAbout_Negar_GUI)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionDonate)
        self.menuHelp.addAction(self.actionReport_Bugs)
        self.menuEdit.addAction(self.actionCopy)
        self.menuEdit.addAction(self.actionPaste)
        self.menuEdit.addAction(self.actionReset)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionQr_Code)
        self.menu_View.addAction(self.actionIncrease_Font_Size)
        self.menu_View.addAction(self.actionDecrease_Font_Size)
        self.menu_View.addSeparator()
        self.menu_View.addAction(self.actionSide_by_Side_View)
        self.menu_View.addAction(self.actionFull_Screen_Input)
        self.menu_View.addAction(self.action_Dark_Mode)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menu_View.menuAction())
        self.menubar.addAction(self.menuSetting.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.font_slider_label.setBuddy(self.font_slider)
        self.input_editor_label.setBuddy(self.input_editor)
        self.output_editor_label.setBuddy(self.output_editor)

        self.retranslateUi(MainWindow)
        self.actionExit.triggered.connect(MainWindow.close) # type: ignore
        self.autoedit_chkbox.toggled['bool'].connect(self.edit_btn.setDisabled) # type: ignore
        self.reset_btn.clicked.connect(self.input_editor.clear) # type: ignore
        self.reset_btn.clicked.connect(self.output_editor.clear) # type: ignore
        self.actionPaste.triggered.connect(self.input_editor.paste) # type: ignore
        self.actionCopy.triggered.connect(self.output_editor.copy) # type: ignore
        self.actionIncrease_Font_Size.triggered.connect(self.input_editor.zoomIn) # type: ignore
        self.actionIncrease_Font_Size.triggered.connect(self.output_editor.zoomIn) # type: ignore
        self.actionDecrease_Font_Size.triggered.connect(self.output_editor.zoomOut) # type: ignore
        self.actionDecrease_Font_Size.triggered.connect(self.input_editor.zoomOut) # type: ignore
        self.actionReset.triggered.connect(self.reset_btn.click) # type: ignore
        self.paste_btn.clicked.connect(self.input_editor.paste) # type: ignore
        self.qrcode_btn.clicked['bool'].connect(self.actionQr_Code.trigger) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.input_editor, self.output_editor)
        MainWindow.setTabOrder(self.output_editor, self.reset_btn)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Negar"))
        self.reset_btn.setToolTip(_translate("MainWindow", "Reset Ctrl+R"))
        self.copy_btn.setToolTip(_translate("MainWindow", "Copy Ctrl+C"))
        self.paste_btn.setToolTip(_translate("MainWindow", "Paste Ctrl+V"))
        self.qrcode_btn.setToolTip(_translate("MainWindow", "QR code"))
        self.vertical_btn.setToolTip(_translate("MainWindow", "vertical view"))
        self.horizontal_btn.setToolTip(_translate("MainWindow", "horizontal view"))
        self.font_slider_label.setText(_translate("MainWindow", "&Font Size"))
        self.edit_btn.setText(_translate("MainWindow", "E&dit"))
        self.autoedit_chkbox.setText(_translate("MainWindow", "Real-&time Edit"))
        self.input_editor_label.setText(_translate("MainWindow", "&Original:"))
        self.output_editor_label.setText(_translate("MainWindow", "Re&vision:"))
        self.menuFile.setTitle(_translate("MainWindow", "&File"))
        self.menuSetting.setTitle(_translate("MainWindow", "&Settings"))
        self.menuOptions.setTitle(_translate("MainWindow", "Editing &Options"))
        self.menuLanguage.setTitle(_translate("MainWindow", "&Language"))
        self.menuHelp.setTitle(_translate("MainWindow", "&Help"))
        self.menuEdit.setTitle(_translate("MainWindow", "&Edit"))
        self.menu_View.setTitle(_translate("MainWindow", "&View"))
        self.actionOpen.setText(_translate("MainWindow", "&Open"))
        self.actionExport.setText(_translate("MainWindow", "&Export"))
        self.actionExit.setText(_translate("MainWindow", "E&xit"))
        self.actionAbout_Negar.setText(_translate("MainWindow", "&About Negar"))
        self.actionDonate.setText(_translate("MainWindow", "&Donate"))
        self.actionReport_Bugs.setText(_translate("MainWindow", "&Report Bugs"))
        self.actionNegar_Help.setText(_translate("MainWindow", "Negar &Help"))
        self.actionFix_Dashes.setText(_translate("MainWindow", "Fix &Dashes"))
        self.actionFix_three_dots.setText(_translate("MainWindow", "Fix &three dots"))
        self.actionFix_English_quotes.setText(_translate("MainWindow", "Fix English &quotes"))
        self.actionFix_hamzeh.setText(_translate("MainWindow", "Fix &hamzeh"))
        self.actionUse_Persian_yeh_to_show_hamzeh.setText(_translate("MainWindow", "Use \'Persian &yeh\' to show hamzeh"))
        self.actionFix_spacing_braces_and_quotes.setText(_translate("MainWindow", "Fix &spacing braces and quotes"))
        self.actionFix_Arabic_numbers.setText(_translate("MainWindow", "Fix Arabic &numbers"))
        self.actionFix_English_numbers.setText(_translate("MainWindow", "Fix &English numbers"))
        self.actionFix_non_Persian_chars.setText(_translate("MainWindow", "Fix non Persian &chars"))
        self.actionFix_prefix_spacing.setText(_translate("MainWindow", "Fix &prefix spacing"))
        self.actionFix_prefix_separating.setText(_translate("MainWindow", "Fix p&refix separating"))
        self.actionFix_suffix_spacing.setText(_translate("MainWindow", "Fix su&ffix spacing"))
        self.actionFix_suffix_separating.setText(_translate("MainWindow", "Fix s&uffix separating"))
        self.actionFix_aggressive_punctuation.setText(_translate("MainWindow", "Fix a&ggressive punctuation"))
        self.actionCleanup_kashidas.setText(_translate("MainWindow", "Cleanup &kashidas"))
        self.actionCleanup_extra_marks.setText(_translate("MainWindow", "Cleanup e&xtra marks"))
        self.actionCleanup_spacing.setText(_translate("MainWindow", "C&leanup spacing"))
        self.actionTrim_Leading_Trailing_Whitespaces.setText(_translate("MainWindow", "Tr&im Leading/Trailing Whitespaces"))
        self.actionExaggerating_ZWNJ.setText(_translate("MainWindow", "Exaggerating &ZWNJ"))
        self.actionUntouchable_Words.setText(_translate("MainWindow", "&Untouchable Words"))
        self.actionPersian.setText(_translate("MainWindow", "&Persian"))
        self.actionEnglish.setText(_translate("MainWindow", "&English"))
        self.actionCopy.setText(_translate("MainWindow", "&Copy"))
        self.actionPaste.setText(_translate("MainWindow", "&Paste"))
        self.actionIncrease_Font_Size.setText(_translate("MainWindow", "&Increase Font Size"))
        self.actionDecrease_Font_Size.setText(_translate("MainWindow", "&Decrease Font Size"))
        self.actionReset.setText(_translate("MainWindow", "&Reset"))
        self.actionSide_by_Side_View.setText(_translate("MainWindow", "&Side-by-Side View"))
        self.actionAbout_Negar_GUI.setText(_translate("MainWindow", "About &Negar-GUI"))
        self.actionInteractive_Clipboard.setText(_translate("MainWindow", "&Interactive Clipboard"))
        self.actionUpdate.setText(_translate("MainWindow", "Update Check"))
        self.actionQr_Code.setText(_translate("MainWindow", "&QR Code"))
        self.actionFull_Screen_Input.setText(_translate("MainWindow", "&Full Screen Input"))
        self.actionFull_Screen_Input.setShortcut(_translate("MainWindow", "Ctrl+F"))
        self.action_Dark_Mode.setText(_translate("MainWindow", "&Dark Mode"))
        self.action_Dark_Mode.setShortcut(_translate("MainWindow", "Ctrl+D"))
from . import resource_rc


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
