# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'mwin.ui'
##
## Created by: Qt User Interface Compiler version 6.2.4
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QAction, QBrush, QColor, QConicalGradient,
    QCursor, QFont, QFontDatabase, QGradient,
    QIcon, QImage, QKeySequence, QLinearGradient,
    QPainter, QPalette, QPixmap, QRadialGradient,
    QTransform)
from PySide6.QtWidgets import (QApplication, QCheckBox, QFrame, QGridLayout,
    QLabel, QMainWindow, QMenu, QMenuBar,
    QPushButton, QSizePolicy, QSlider, QSpacerItem,
    QStatusBar, QTextEdit, QVBoxLayout, QWidget)
import resource_rc

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(1059, 790)
        MainWindow.setFocusPolicy(Qt.StrongFocus)
        MainWindow.setLayoutDirection(Qt.LeftToRight)
        MainWindow.setAutoFillBackground(False)
        MainWindow.setStyleSheet(u"QFrame {\n"
"	border: none;\n"
"	margin: 0px;\n"
"	padding: 0px;\n"
"}")
        self.actionOpen = QAction(MainWindow)
        self.actionOpen.setObjectName(u"actionOpen")
        icon = QIcon()
        icon.addFile(u":/images/icons/open.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionOpen.setIcon(icon)
#if QT_CONFIG(shortcut)
        self.actionOpen.setShortcut(u"Ctrl+O")
#endif // QT_CONFIG(shortcut)
        self.actionExport = QAction(MainWindow)
        self.actionExport.setObjectName(u"actionExport")
        icon1 = QIcon()
        icon1.addFile(u":/images/icons/export.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionExport.setIcon(icon1)
#if QT_CONFIG(shortcut)
        self.actionExport.setShortcut(u"Ctrl+E")
#endif // QT_CONFIG(shortcut)
        self.actionExit = QAction(MainWindow)
        self.actionExit.setObjectName(u"actionExit")
        icon2 = QIcon()
        icon2.addFile(u":/images/icons/exit.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionExit.setIcon(icon2)
#if QT_CONFIG(shortcut)
        self.actionExit.setShortcut(u"Ctrl+Q")
#endif // QT_CONFIG(shortcut)
        self.actionAbout_Negar = QAction(MainWindow)
        self.actionAbout_Negar.setObjectName(u"actionAbout_Negar")
        icon3 = QIcon()
        icon3.addFile(u":/images/icons/about.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionAbout_Negar.setIcon(icon3)
#if QT_CONFIG(shortcut)
        self.actionAbout_Negar.setShortcut(u"")
#endif // QT_CONFIG(shortcut)
        self.actionDonate = QAction(MainWindow)
        self.actionDonate.setObjectName(u"actionDonate")
        self.actionDonate.setEnabled(False)
        icon4 = QIcon()
        icon4.addFile(u":/images/icons/donate.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionDonate.setIcon(icon4)
#if QT_CONFIG(shortcut)
        self.actionDonate.setShortcut(u"")
#endif // QT_CONFIG(shortcut)
        self.actionReport_Bugs = QAction(MainWindow)
        self.actionReport_Bugs.setObjectName(u"actionReport_Bugs")
        icon5 = QIcon()
        icon5.addFile(u":/images/icons/bugs.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionReport_Bugs.setIcon(icon5)
        self.actionNegar_Help = QAction(MainWindow)
        self.actionNegar_Help.setObjectName(u"actionNegar_Help")
        icon6 = QIcon()
        icon6.addFile(u":/images/icons/logo.png", QSize(), QIcon.Normal, QIcon.Off)
        self.actionNegar_Help.setIcon(icon6)
#if QT_CONFIG(shortcut)
        self.actionNegar_Help.setShortcut(u"F1")
#endif // QT_CONFIG(shortcut)
        self.actionFix_Dashes = QAction(MainWindow)
        self.actionFix_Dashes.setObjectName(u"actionFix_Dashes")
        self.actionFix_Dashes.setCheckable(True)
        self.actionFix_Dashes.setChecked(True)
        self.actionFix_three_dots = QAction(MainWindow)
        self.actionFix_three_dots.setObjectName(u"actionFix_three_dots")
        self.actionFix_three_dots.setCheckable(True)
        self.actionFix_three_dots.setChecked(True)
        self.actionFix_English_quotes = QAction(MainWindow)
        self.actionFix_English_quotes.setObjectName(u"actionFix_English_quotes")
        self.actionFix_English_quotes.setCheckable(True)
        self.actionFix_English_quotes.setChecked(True)
        self.actionFix_hamzeh = QAction(MainWindow)
        self.actionFix_hamzeh.setObjectName(u"actionFix_hamzeh")
        self.actionFix_hamzeh.setCheckable(True)
        self.actionFix_hamzeh.setChecked(True)
        self.actionUse_Persian_yeh_to_show_hamzeh = QAction(MainWindow)
        self.actionUse_Persian_yeh_to_show_hamzeh.setObjectName(u"actionUse_Persian_yeh_to_show_hamzeh")
        self.actionUse_Persian_yeh_to_show_hamzeh.setCheckable(True)
        self.actionUse_Persian_yeh_to_show_hamzeh.setChecked(True)
        self.actionFix_spacing_braces_and_quotes = QAction(MainWindow)
        self.actionFix_spacing_braces_and_quotes.setObjectName(u"actionFix_spacing_braces_and_quotes")
        self.actionFix_spacing_braces_and_quotes.setCheckable(True)
        self.actionFix_spacing_braces_and_quotes.setChecked(True)
        self.actionFix_Arabic_numbers = QAction(MainWindow)
        self.actionFix_Arabic_numbers.setObjectName(u"actionFix_Arabic_numbers")
        self.actionFix_Arabic_numbers.setCheckable(True)
        self.actionFix_Arabic_numbers.setChecked(True)
        self.actionFix_English_numbers = QAction(MainWindow)
        self.actionFix_English_numbers.setObjectName(u"actionFix_English_numbers")
        self.actionFix_English_numbers.setCheckable(True)
        self.actionFix_English_numbers.setChecked(True)
        self.actionFix_non_Persian_chars = QAction(MainWindow)
        self.actionFix_non_Persian_chars.setObjectName(u"actionFix_non_Persian_chars")
        self.actionFix_non_Persian_chars.setCheckable(True)
        self.actionFix_non_Persian_chars.setChecked(True)
        self.actionFix_prefix_spacing = QAction(MainWindow)
        self.actionFix_prefix_spacing.setObjectName(u"actionFix_prefix_spacing")
        self.actionFix_prefix_spacing.setCheckable(True)
        self.actionFix_prefix_spacing.setChecked(True)
        self.actionFix_prefix_separating = QAction(MainWindow)
        self.actionFix_prefix_separating.setObjectName(u"actionFix_prefix_separating")
        self.actionFix_prefix_separating.setCheckable(True)
        self.actionFix_prefix_separating.setChecked(True)
        self.actionFix_suffix_spacing = QAction(MainWindow)
        self.actionFix_suffix_spacing.setObjectName(u"actionFix_suffix_spacing")
        self.actionFix_suffix_spacing.setCheckable(True)
        self.actionFix_suffix_spacing.setChecked(True)
        self.actionFix_suffix_separating = QAction(MainWindow)
        self.actionFix_suffix_separating.setObjectName(u"actionFix_suffix_separating")
        self.actionFix_suffix_separating.setCheckable(True)
        self.actionFix_suffix_separating.setChecked(True)
        self.actionFix_aggressive_punctuation = QAction(MainWindow)
        self.actionFix_aggressive_punctuation.setObjectName(u"actionFix_aggressive_punctuation")
        self.actionFix_aggressive_punctuation.setCheckable(True)
        self.actionFix_aggressive_punctuation.setChecked(True)
        self.actionCleanup_kashidas = QAction(MainWindow)
        self.actionCleanup_kashidas.setObjectName(u"actionCleanup_kashidas")
        self.actionCleanup_kashidas.setCheckable(True)
        self.actionCleanup_kashidas.setChecked(True)
        self.actionCleanup_extra_marks = QAction(MainWindow)
        self.actionCleanup_extra_marks.setObjectName(u"actionCleanup_extra_marks")
        self.actionCleanup_extra_marks.setCheckable(True)
        self.actionCleanup_extra_marks.setChecked(True)
        self.actionCleanup_spacing = QAction(MainWindow)
        self.actionCleanup_spacing.setObjectName(u"actionCleanup_spacing")
        self.actionCleanup_spacing.setCheckable(True)
        self.actionCleanup_spacing.setChecked(True)
        self.actionTrim_Leading_Trailing_Whitespaces = QAction(MainWindow)
        self.actionTrim_Leading_Trailing_Whitespaces.setObjectName(u"actionTrim_Leading_Trailing_Whitespaces")
        self.actionTrim_Leading_Trailing_Whitespaces.setCheckable(True)
        self.actionTrim_Leading_Trailing_Whitespaces.setChecked(True)
        self.actionExaggerating_ZWNJ = QAction(MainWindow)
        self.actionExaggerating_ZWNJ.setObjectName(u"actionExaggerating_ZWNJ")
        self.actionExaggerating_ZWNJ.setCheckable(True)
        self.actionExaggerating_ZWNJ.setChecked(True)
        self.actionUntouchable_Words = QAction(MainWindow)
        self.actionUntouchable_Words.setObjectName(u"actionUntouchable_Words")
        icon7 = QIcon()
        icon7.addFile(u":/images/icons/words.png", QSize(), QIcon.Normal, QIcon.Off)
        self.actionUntouchable_Words.setIcon(icon7)
#if QT_CONFIG(shortcut)
        self.actionUntouchable_Words.setShortcut(u"")
#endif // QT_CONFIG(shortcut)
        self.actionPersian = QAction(MainWindow)
        self.actionPersian.setObjectName(u"actionPersian")
        icon8 = QIcon()
        icon8.addFile(u":/images/icons/Fa.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionPersian.setIcon(icon8)
#if QT_CONFIG(shortcut)
        self.actionPersian.setShortcut(u"Ctrl+L, Ctrl+F")
#endif // QT_CONFIG(shortcut)
        self.actionEnglish = QAction(MainWindow)
        self.actionEnglish.setObjectName(u"actionEnglish")
        icon9 = QIcon()
        icon9.addFile(u":/images/icons/En.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionEnglish.setIcon(icon9)
#if QT_CONFIG(shortcut)
        self.actionEnglish.setShortcut(u"Ctrl+L, Ctrl+E")
#endif // QT_CONFIG(shortcut)
        self.actionCopy = QAction(MainWindow)
        self.actionCopy.setObjectName(u"actionCopy")
        icon10 = QIcon()
        icon10.addFile(u":/images/icons/copy.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionCopy.setIcon(icon10)
#if QT_CONFIG(shortcut)
        self.actionCopy.setShortcut(u"Ctrl+C")
#endif // QT_CONFIG(shortcut)
        self.actionPaste = QAction(MainWindow)
        self.actionPaste.setObjectName(u"actionPaste")
        icon11 = QIcon()
        icon11.addFile(u":/images/icons/paste.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionPaste.setIcon(icon11)
#if QT_CONFIG(shortcut)
        self.actionPaste.setShortcut(u"Ctrl+V")
#endif // QT_CONFIG(shortcut)
        self.actionIncrease_Font_Size = QAction(MainWindow)
        self.actionIncrease_Font_Size.setObjectName(u"actionIncrease_Font_Size")
        icon12 = QIcon()
        icon12.addFile(u":/images/icons/increase.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionIncrease_Font_Size.setIcon(icon12)
#if QT_CONFIG(shortcut)
        self.actionIncrease_Font_Size.setShortcut(u"Ctrl+=")
#endif // QT_CONFIG(shortcut)
        self.actionDecrease_Font_Size = QAction(MainWindow)
        self.actionDecrease_Font_Size.setObjectName(u"actionDecrease_Font_Size")
        icon13 = QIcon()
        icon13.addFile(u":/images/icons/decrease.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionDecrease_Font_Size.setIcon(icon13)
#if QT_CONFIG(shortcut)
        self.actionDecrease_Font_Size.setShortcut(u"Ctrl+-")
#endif // QT_CONFIG(shortcut)
        self.actionReset = QAction(MainWindow)
        self.actionReset.setObjectName(u"actionReset")
        icon14 = QIcon()
        icon14.addFile(u":/images/icons/reset.png", QSize(), QIcon.Normal, QIcon.Off)
        self.actionReset.setIcon(icon14)
#if QT_CONFIG(shortcut)
        self.actionReset.setShortcut(u"Ctrl+R")
#endif // QT_CONFIG(shortcut)
        self.actionSide_by_Side_View = QAction(MainWindow)
        self.actionSide_by_Side_View.setObjectName(u"actionSide_by_Side_View")
        self.actionSide_by_Side_View.setCheckable(True)
#if QT_CONFIG(shortcut)
        self.actionSide_by_Side_View.setShortcut(u"Ctrl+S")
#endif // QT_CONFIG(shortcut)
        self.actionAbout_Negar_GUI = QAction(MainWindow)
        self.actionAbout_Negar_GUI.setObjectName(u"actionAbout_Negar_GUI")
        self.actionInteractive_Clipboard = QAction(MainWindow)
        self.actionInteractive_Clipboard.setObjectName(u"actionInteractive_Clipboard")
        self.actionInteractive_Clipboard.setCheckable(True)
#if QT_CONFIG(shortcut)
        self.actionInteractive_Clipboard.setShortcut(u"Ctrl+I")
#endif // QT_CONFIG(shortcut)
        self.actionUpdate = QAction(MainWindow)
        self.actionUpdate.setObjectName(u"actionUpdate")
        self.actionQr_Code = QAction(MainWindow)
        self.actionQr_Code.setObjectName(u"actionQr_Code")
        icon15 = QIcon()
        icon15.addFile(u":/images/icons/qr.png", QSize(), QIcon.Normal, QIcon.Off)
        self.actionQr_Code.setIcon(icon15)
        self.actionFull_Screen_Input = QAction(MainWindow)
        self.actionFull_Screen_Input.setObjectName(u"actionFull_Screen_Input")
        self.actionFull_Screen_Input.setCheckable(True)
        self.action_Dark_Mode = QAction(MainWindow)
        self.action_Dark_Mode.setObjectName(u"action_Dark_Mode")
        self.action_Dark_Mode.setCheckable(True)
        self.action_Dark_Mode.setEnabled(False)
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.centralwidget.setEnabled(True)
        sizePolicy = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setFocusPolicy(Qt.StrongFocus)
        self.centralwidget.setLayoutDirection(Qt.LeftToRight)
        self.centralwidget.setAutoFillBackground(True)
        self.gridLayout_6 = QGridLayout(self.centralwidget)
        self.gridLayout_6.setObjectName(u"gridLayout_6")
        self.frame_6 = QFrame(self.centralwidget)
        self.frame_6.setObjectName(u"frame_6")
        self.frame_6.setFrameShape(QFrame.StyledPanel)
        self.frame_6.setFrameShadow(QFrame.Raised)
        self.verticalLayout = QVBoxLayout(self.frame_6)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.frame = QFrame(self.frame_6)
        self.frame.setObjectName(u"frame")
        sizePolicy1 = QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy1)
        self.frame.setFrameShape(QFrame.StyledPanel)
        self.frame.setFrameShadow(QFrame.Raised)
        self.gridLayout_5 = QGridLayout(self.frame)
        self.gridLayout_5.setObjectName(u"gridLayout_5")
        self.gridLayout_5.setContentsMargins(0, 0, 0, 0)
        self.frame_2 = QFrame(self.frame)
        self.frame_2.setObjectName(u"frame_2")
        self.frame_2.setFrameShape(QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QFrame.Raised)
        self.gridLayout_4 = QGridLayout(self.frame_2)
        self.gridLayout_4.setSpacing(0)
        self.gridLayout_4.setObjectName(u"gridLayout_4")
        self.gridLayout_4.setContentsMargins(0, 0, 0, 0)
        self.reset_btn = QPushButton(self.frame_2)
        self.reset_btn.setObjectName(u"reset_btn")
        self.reset_btn.setStyleSheet(u"")
        self.reset_btn.setIcon(icon14)
#if QT_CONFIG(shortcut)
        self.reset_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.reset_btn, 0, 0, 1, 1)

        self.copy_btn = QPushButton(self.frame_2)
        self.copy_btn.setObjectName(u"copy_btn")
        icon16 = QIcon()
        icon16.addFile(u":/images/icons/copy.png", QSize(), QIcon.Normal, QIcon.Off)
        self.copy_btn.setIcon(icon16)
#if QT_CONFIG(shortcut)
        self.copy_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.copy_btn, 0, 1, 1, 1)

        self.paste_btn = QPushButton(self.frame_2)
        self.paste_btn.setObjectName(u"paste_btn")
        self.paste_btn.setIcon(icon11)
#if QT_CONFIG(shortcut)
        self.paste_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.paste_btn, 0, 2, 1, 1)

        self.qrcode_btn = QPushButton(self.frame_2)
        self.qrcode_btn.setObjectName(u"qrcode_btn")
        self.qrcode_btn.setIcon(icon15)
#if QT_CONFIG(shortcut)
        self.qrcode_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.qrcode_btn, 0, 3, 1, 1)

        self.vertical_btn = QPushButton(self.frame_2)
        self.vertical_btn.setObjectName(u"vertical_btn")
        icon17 = QIcon()
        icon17.addFile(u":/images/icons/vertical.png", QSize(), QIcon.Normal, QIcon.Off)
        self.vertical_btn.setIcon(icon17)
#if QT_CONFIG(shortcut)
        self.vertical_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.vertical_btn, 0, 4, 1, 1)

        self.horizontal_btn = QPushButton(self.frame_2)
        self.horizontal_btn.setObjectName(u"horizontal_btn")
        icon18 = QIcon()
        icon18.addFile(u":/images/icons/horizontal.png", QSize(), QIcon.Normal, QIcon.Off)
        self.horizontal_btn.setIcon(icon18)
#if QT_CONFIG(shortcut)
        self.horizontal_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.horizontal_btn, 0, 5, 1, 1)


        self.gridLayout_5.addWidget(self.frame_2, 0, 0, 1, 1)

        self.horizontalSpacer = QSpacerItem(210, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_5.addItem(self.horizontalSpacer, 0, 1, 1, 1)

        self.horizontalSpacer_2 = QSpacerItem(210, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_5.addItem(self.horizontalSpacer_2, 0, 2, 1, 1)

        self.frame_4 = QFrame(self.frame)
        self.frame_4.setObjectName(u"frame_4")
        self.frame_4.setFrameShape(QFrame.StyledPanel)
        self.frame_4.setFrameShadow(QFrame.Raised)
        self.gridLayout_3 = QGridLayout(self.frame_4)
        self.gridLayout_3.setObjectName(u"gridLayout_3")
        self.gridLayout_3.setVerticalSpacing(0)
        self.gridLayout_3.setContentsMargins(0, 0, 0, 0)
        self.font_slider_label = QLabel(self.frame_4)
        self.font_slider_label.setObjectName(u"font_slider_label")

        self.gridLayout_3.addWidget(self.font_slider_label, 0, 0, 1, 1)

        self.font_slider = QSlider(self.frame_4)
        self.font_slider.setObjectName(u"font_slider")
        self.font_slider.setMinimum(10)
        self.font_slider.setMaximum(72)
        self.font_slider.setValue(18)
        self.font_slider.setOrientation(Qt.Horizontal)

        self.gridLayout_3.addWidget(self.font_slider, 0, 1, 1, 1)


        self.gridLayout_5.addWidget(self.frame_4, 0, 3, 1, 1)

        self.frame_3 = QFrame(self.frame)
        self.frame_3.setObjectName(u"frame_3")
        self.frame_3.setFrameShape(QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QFrame.Raised)
        self.gridLayout_7 = QGridLayout(self.frame_3)
        self.gridLayout_7.setObjectName(u"gridLayout_7")
        self.gridLayout_7.setVerticalSpacing(0)
        self.gridLayout_7.setContentsMargins(0, 0, 0, 0)
        self.edit_btn = QPushButton(self.frame_3)
        self.edit_btn.setObjectName(u"edit_btn")
        self.edit_btn.setEnabled(False)
        icon19 = QIcon()
        icon19.addFile(u":/images/icons/edit.png", QSize(), QIcon.Normal, QIcon.Off)
        self.edit_btn.setIcon(icon19)

        self.gridLayout_7.addWidget(self.edit_btn, 0, 1, 1, 1)

        self.autoedit_chkbox = QCheckBox(self.frame_3)
        self.autoedit_chkbox.setObjectName(u"autoedit_chkbox")
        self.autoedit_chkbox.setLayoutDirection(Qt.RightToLeft)
        self.autoedit_chkbox.setChecked(True)

        self.gridLayout_7.addWidget(self.autoedit_chkbox, 0, 0, 1, 1)


        self.gridLayout_5.addWidget(self.frame_3, 0, 4, 1, 1)


        self.verticalLayout.addWidget(self.frame)

        self.frame_5 = QFrame(self.frame_6)
        self.frame_5.setObjectName(u"frame_5")
        self.frame_5.setFrameShape(QFrame.StyledPanel)
        self.frame_5.setFrameShadow(QFrame.Raised)
        self.gridLayout_2 = QGridLayout(self.frame_5)
        self.gridLayout_2.setSpacing(0)
        self.gridLayout_2.setObjectName(u"gridLayout_2")
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout = QGridLayout()
        self.gridLayout.setObjectName(u"gridLayout")
        self.input_layout = QGridLayout()
        self.input_layout.setObjectName(u"input_layout")
        self.input_editor_label = QLabel(self.frame_5)
        self.input_editor_label.setObjectName(u"input_editor_label")

        self.input_layout.addWidget(self.input_editor_label, 0, 0, 1, 1)

        self.input_editor = QTextEdit(self.frame_5)
        self.input_editor.setObjectName(u"input_editor")

        self.input_layout.addWidget(self.input_editor, 1, 0, 1, 1)


        self.gridLayout.addLayout(self.input_layout, 0, 0, 1, 1)

        self.output_editor_label = QLabel(self.frame_5)
        self.output_editor_label.setObjectName(u"output_editor_label")

        self.gridLayout.addWidget(self.output_editor_label, 1, 0, 1, 1)

        self.output_editor = QTextEdit(self.frame_5)
        self.output_editor.setObjectName(u"output_editor")

        self.gridLayout.addWidget(self.output_editor, 2, 0, 1, 1)


        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 1)


        self.verticalLayout.addWidget(self.frame_5)


        self.gridLayout_6.addWidget(self.frame_6, 0, 0, 1, 1)

        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QMenuBar(MainWindow)
        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 1059, 27))
        self.menuFile = QMenu(self.menubar)
        self.menuFile.setObjectName(u"menuFile")
        self.menuSetting = QMenu(self.menubar)
        self.menuSetting.setObjectName(u"menuSetting")
        self.menuOptions = QMenu(self.menuSetting)
        self.menuOptions.setObjectName(u"menuOptions")
        icon20 = QIcon()
        icon20.addFile(u":/images/icons/options.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.menuOptions.setIcon(icon20)
        self.menuOptions.setSeparatorsCollapsible(True)
        self.menuLanguage = QMenu(self.menuSetting)
        self.menuLanguage.setObjectName(u"menuLanguage")
        icon21 = QIcon()
        icon21.addFile(u":/images/icons/languages.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.menuLanguage.setIcon(icon21)
        self.menuHelp = QMenu(self.menubar)
        self.menuHelp.setObjectName(u"menuHelp")
        sizePolicy2 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
        sizePolicy2.setHorizontalStretch(0)
        sizePolicy2.setVerticalStretch(0)
        sizePolicy2.setHeightForWidth(self.menuHelp.sizePolicy().hasHeightForWidth())
        self.menuHelp.setSizePolicy(sizePolicy2)
        self.menuEdit = QMenu(self.menubar)
        self.menuEdit.setObjectName(u"menuEdit")
        self.menu_View = QMenu(self.menubar)
        self.menu_View.setObjectName(u"menu_View")
        MainWindow.setMenuBar(self.menubar)
        self.statusBar = QStatusBar(MainWindow)
        self.statusBar.setObjectName(u"statusBar")
        MainWindow.setStatusBar(self.statusBar)
#if QT_CONFIG(shortcut)
        self.font_slider_label.setBuddy(self.font_slider)
        self.input_editor_label.setBuddy(self.input_editor)
        self.output_editor_label.setBuddy(self.output_editor)
#endif // QT_CONFIG(shortcut)
        QWidget.setTabOrder(self.input_editor, self.output_editor)
        QWidget.setTabOrder(self.output_editor, self.reset_btn)

        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menu_View.menuAction())
        self.menubar.addAction(self.menuSetting.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addAction(self.actionExport)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menuSetting.addAction(self.menuOptions.menuAction())
        self.menuSetting.addAction(self.actionInteractive_Clipboard)
        self.menuSetting.addAction(self.menuLanguage.menuAction())
        self.menuSetting.addSeparator()
        self.menuSetting.addAction(self.actionUntouchable_Words)
        self.menuOptions.addAction(self.actionFix_Dashes)
        self.menuOptions.addAction(self.actionFix_three_dots)
        self.menuOptions.addAction(self.actionFix_English_quotes)
        self.menuOptions.addAction(self.actionFix_hamzeh)
        self.menuOptions.addAction(self.actionFix_spacing_braces_and_quotes)
        self.menuOptions.addAction(self.actionFix_Arabic_numbers)
        self.menuOptions.addAction(self.actionFix_English_numbers)
        self.menuOptions.addAction(self.actionFix_non_Persian_chars)
        self.menuOptions.addAction(self.actionFix_prefix_spacing)
        self.menuOptions.addAction(self.actionFix_prefix_separating)
        self.menuOptions.addAction(self.actionFix_suffix_spacing)
        self.menuOptions.addAction(self.actionFix_suffix_separating)
        self.menuOptions.addAction(self.actionFix_aggressive_punctuation)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionUse_Persian_yeh_to_show_hamzeh)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionCleanup_spacing)
        self.menuOptions.addAction(self.actionCleanup_kashidas)
        self.menuOptions.addAction(self.actionCleanup_extra_marks)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionExaggerating_ZWNJ)
        self.menuOptions.addAction(self.actionTrim_Leading_Trailing_Whitespaces)
        self.menuLanguage.addAction(self.actionPersian)
        self.menuLanguage.addAction(self.actionEnglish)
        self.menuHelp.addAction(self.actionNegar_Help)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbout_Negar)
        self.menuHelp.addAction(self.actionAbout_Negar_GUI)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionDonate)
        self.menuHelp.addAction(self.actionReport_Bugs)
        self.menuEdit.addAction(self.actionCopy)
        self.menuEdit.addAction(self.actionPaste)
        self.menuEdit.addAction(self.actionReset)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionQr_Code)
        self.menu_View.addAction(self.actionIncrease_Font_Size)
        self.menu_View.addAction(self.actionDecrease_Font_Size)
        self.menu_View.addSeparator()
        self.menu_View.addAction(self.actionSide_by_Side_View)
        self.menu_View.addAction(self.actionFull_Screen_Input)
        self.menu_View.addAction(self.action_Dark_Mode)

        self.retranslateUi(MainWindow)
        self.actionExit.triggered.connect(MainWindow.close)
        self.autoedit_chkbox.toggled.connect(self.edit_btn.setDisabled)
        self.reset_btn.clicked.connect(self.input_editor.clear)
        self.reset_btn.clicked.connect(self.output_editor.clear)
        self.actionPaste.triggered.connect(self.input_editor.paste)
        self.actionCopy.triggered.connect(self.output_editor.copy)
        self.actionIncrease_Font_Size.triggered.connect(self.input_editor.zoomIn)
        self.actionIncrease_Font_Size.triggered.connect(self.output_editor.zoomIn)
        self.actionDecrease_Font_Size.triggered.connect(self.output_editor.zoomOut)
        self.actionDecrease_Font_Size.triggered.connect(self.input_editor.zoomOut)
        self.actionReset.triggered.connect(self.reset_btn.click)
        self.paste_btn.clicked.connect(self.input_editor.paste)
        self.qrcode_btn.clicked["bool"].connect(self.actionQr_Code.trigger)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"Negar", None))
        self.actionOpen.setText(QCoreApplication.translate("MainWindow", u"&Open", None))
        self.actionExport.setText(QCoreApplication.translate("MainWindow", u"&Export", None))
        self.actionExit.setText(QCoreApplication.translate("MainWindow", u"E&xit", None))
        self.actionAbout_Negar.setText(QCoreApplication.translate("MainWindow", u"&About Negar", None))
        self.actionDonate.setText(QCoreApplication.translate("MainWindow", u"&Donate", None))
        self.actionReport_Bugs.setText(QCoreApplication.translate("MainWindow", u"&Report Bugs", None))
        self.actionNegar_Help.setText(QCoreApplication.translate("MainWindow", u"Negar &Help", None))
        self.actionFix_Dashes.setText(QCoreApplication.translate("MainWindow", u"Fix &Dashes", None))
        self.actionFix_three_dots.setText(QCoreApplication.translate("MainWindow", u"Fix &three dots", None))
        self.actionFix_English_quotes.setText(QCoreApplication.translate("MainWindow", u"Fix English &quotes", None))
        self.actionFix_hamzeh.setText(QCoreApplication.translate("MainWindow", u"Fix &hamzeh", None))
        self.actionUse_Persian_yeh_to_show_hamzeh.setText(QCoreApplication.translate("MainWindow", u"Use 'Persian &yeh' to show hamzeh", None))
        self.actionFix_spacing_braces_and_quotes.setText(QCoreApplication.translate("MainWindow", u"Fix &spacing braces and quotes", None))
        self.actionFix_Arabic_numbers.setText(QCoreApplication.translate("MainWindow", u"Fix Arabic &numbers", None))
        self.actionFix_English_numbers.setText(QCoreApplication.translate("MainWindow", u"Fix &English numbers", None))
        self.actionFix_non_Persian_chars.setText(QCoreApplication.translate("MainWindow", u"Fix non Persian &chars", None))
        self.actionFix_prefix_spacing.setText(QCoreApplication.translate("MainWindow", u"Fix &prefix spacing", None))
        self.actionFix_prefix_separating.setText(QCoreApplication.translate("MainWindow", u"Fix p&refix separating", None))
        self.actionFix_suffix_spacing.setText(QCoreApplication.translate("MainWindow", u"Fix su&ffix spacing", None))
        self.actionFix_suffix_separating.setText(QCoreApplication.translate("MainWindow", u"Fix s&uffix separating", None))
        self.actionFix_aggressive_punctuation.setText(QCoreApplication.translate("MainWindow", u"Fix a&ggressive punctuation", None))
        self.actionCleanup_kashidas.setText(QCoreApplication.translate("MainWindow", u"Cleanup &kashidas", None))
        self.actionCleanup_extra_marks.setText(QCoreApplication.translate("MainWindow", u"Cleanup e&xtra marks", None))
        self.actionCleanup_spacing.setText(QCoreApplication.translate("MainWindow", u"C&leanup spacing", None))
        self.actionTrim_Leading_Trailing_Whitespaces.setText(QCoreApplication.translate("MainWindow", u"Tr&im Leading/Trailing Whitespaces", None))
        self.actionExaggerating_ZWNJ.setText(QCoreApplication.translate("MainWindow", u"Exaggerating &ZWNJ", None))
        self.actionUntouchable_Words.setText(QCoreApplication.translate("MainWindow", u"&Untouchable Words", None))
        self.actionPersian.setText(QCoreApplication.translate("MainWindow", u"&Persian", None))
        self.actionEnglish.setText(QCoreApplication.translate("MainWindow", u"&English", None))
        self.actionCopy.setText(QCoreApplication.translate("MainWindow", u"&Copy", None))
        self.actionPaste.setText(QCoreApplication.translate("MainWindow", u"&Paste", None))
        self.actionIncrease_Font_Size.setText(QCoreApplication.translate("MainWindow", u"&Increase Font Size", None))
        self.actionDecrease_Font_Size.setText(QCoreApplication.translate("MainWindow", u"&Decrease Font Size", None))
        self.actionReset.setText(QCoreApplication.translate("MainWindow", u"&Reset", None))
        self.actionSide_by_Side_View.setText(QCoreApplication.translate("MainWindow", u"&Side-by-Side View", None))
        self.actionAbout_Negar_GUI.setText(QCoreApplication.translate("MainWindow", u"About &Negar-GUI", None))
        self.actionInteractive_Clipboard.setText(QCoreApplication.translate("MainWindow", u"&Interactive Clipboard", None))
        self.actionUpdate.setText(QCoreApplication.translate("MainWindow", u"Update Check", None))
        self.actionQr_Code.setText(QCoreApplication.translate("MainWindow", u"&QR Code", None))
        self.actionFull_Screen_Input.setText(QCoreApplication.translate("MainWindow", u"&Full Screen Input", None))
#if QT_CONFIG(shortcut)
        self.actionFull_Screen_Input.setShortcut(QCoreApplication.translate("MainWindow", u"Ctrl+F", None))
#endif // QT_CONFIG(shortcut)
        self.action_Dark_Mode.setText(QCoreApplication.translate("MainWindow", u"&Dark Mode", None))
#if QT_CONFIG(shortcut)
        self.action_Dark_Mode.setShortcut(QCoreApplication.translate("MainWindow", u"Ctrl+D", None))
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(tooltip)
        self.reset_btn.setToolTip(QCoreApplication.translate("MainWindow", u"Reset Ctrl+R", None))
#endif // QT_CONFIG(tooltip)
        self.reset_btn.setText("")
#if QT_CONFIG(tooltip)
        self.copy_btn.setToolTip(QCoreApplication.translate("MainWindow", u"Copy Ctrl+C", None))
#endif // QT_CONFIG(tooltip)
        self.copy_btn.setText("")
#if QT_CONFIG(tooltip)
        self.paste_btn.setToolTip(QCoreApplication.translate("MainWindow", u"Paste Ctrl+V", None))
#endif // QT_CONFIG(tooltip)
        self.paste_btn.setText("")
#if QT_CONFIG(tooltip)
        self.qrcode_btn.setToolTip(QCoreApplication.translate("MainWindow", u"QR code", None))
#endif // QT_CONFIG(tooltip)
        self.qrcode_btn.setText("")
#if QT_CONFIG(tooltip)
        self.vertical_btn.setToolTip(QCoreApplication.translate("MainWindow", u"vertical view", None))
#endif // QT_CONFIG(tooltip)
        self.vertical_btn.setText("")
#if QT_CONFIG(tooltip)
        self.horizontal_btn.setToolTip(QCoreApplication.translate("MainWindow", u"horizontal view", None))
#endif // QT_CONFIG(tooltip)
        self.horizontal_btn.setText("")
        self.font_slider_label.setText(QCoreApplication.translate("MainWindow", u"&Font Size", None))
        self.edit_btn.setText(QCoreApplication.translate("MainWindow", u"E&dit", None))
        self.autoedit_chkbox.setText(QCoreApplication.translate("MainWindow", u"Real-&time Edit", None))
        self.input_editor_label.setText(QCoreApplication.translate("MainWindow", u"&Original:", None))
        self.output_editor_label.setText(QCoreApplication.translate("MainWindow", u"Re&vision:", None))
        self.menuFile.setTitle(QCoreApplication.translate("MainWindow", u"&File", None))
        self.menuSetting.setTitle(QCoreApplication.translate("MainWindow", u"&Settings", None))
        self.menuOptions.setTitle(QCoreApplication.translate("MainWindow", u"Editing &Options", None))
        self.menuLanguage.setTitle(QCoreApplication.translate("MainWindow", u"&Language", None))
        self.menuHelp.setTitle(QCoreApplication.translate("MainWindow", u"&Help", None))
        self.menuEdit.setTitle(QCoreApplication.translate("MainWindow", u"&Edit", None))
        self.menu_View.setTitle(QCoreApplication.translate("MainWindow", u"&View", None))
    # retranslateUi

